import React, { PureComponent } from 'react';
import { Table } from 'antd';

export default class StandardTableList extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      selectedRowKeys: [],
    }
  }
  componentWillReceiveProps(nextProps) {
    if (nextProps.selectedRows.length === 0) {
      this.setState({
        selectedRowKeys: [],
      });
    }
  }
  handleRowSelectChange = (selectedRowKeys, selectedRows) => {
    if (this.props.onSelectRow) {
      this.props.onSelectRow(selectedRows);
    }
    this.setState({ selectedRowKeys });
  }
  handleTableChange = (pagination, filters, sorter) => {
    this.props.onChange(pagination, filters, sorter);
  }
  cleanSelectedKeys = () => {
    this.handleRowSelectChange([], []);
  }

  render() {
    const {
      loading,
      columns,
      onChange,
      dataSource,
      pagination,
    } = this.props;
    const { selectedRowKeys } = this.state;
    const paginationProps = {
      showSizeChanger: true,
      showQuickJumper: true,
      ...pagination,
    };
    const rowSelection = {
      selectedRowKeys,
      onChange: this.handleRowSelectChange,
      getCheckboxProps: record => ({
        disabled: record.disabled,
      }),
    };
    return (
      <Table
        loading={loading}
        rowKey={record => record.key}
        rowSelection={rowSelection}
        columns={columns}
        dataSource={dataSource}
        pagination={paginationProps}
      />
    );
  }
}
