import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, message, Button, Icon, Modal } from 'antd';
import { PictureItem } from '../../components/RBItem';
import { StandardCardList } from '../../components/RBList';

const Message = message;

function pictureItemFormatter(originData) {
  return originData.map(item => {
    return {
      id: item.id,
      picPath: item.path,
      picName: item.name,
      picCode: item.code,
      picStatus: item.state,
    };
  });
}

@connect(({ resource, loading })=> ({
  resource,
  loading: loading.models.resource,
}))
export default class PictureList extends PureComponent {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      UIParams: (state || {}).UIParams, //组件的状态参数
      Queryers: (state || {}).Queryers, //查询的条件参数
    }
  }
  state = {
    UIParams: {},
    Queryers: {},
  };
  componentDidMount() {
    this.props.dispatch({
      type: 'resource/fetchImageList',
      payload: {...this.state.Queryers},
    });
  }
  //增加
  handleCreateOperation = () => {
    //页面跳转把这些参数传递过去，返回的时候再传回来，来保证组件等状态不变
    const { Queryers, UIParams } = this.state;
    this.props.dispatch(
      routerRedux.push({
        pathname: '/resource/imageCreate/single',
        state: {
          Queryers,
          UIParams,
        },
      })
    );
  }
  //删除
  handleDeleteOperation = (item) => {
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: '你确定要删除这张图片吗?',
      content: '删除后所有与之关联的课件将不再显示该图片',
      onOk: () => {
        this.props.dispatch({
          type: 'resource/deleteImage',
          payload: {id:item.id},
        });
      },
    });
  }
  //修改
  handleEditOperation = () => {

  }
  //查询
  handleFilterOperation = (params, states) => {
    this.props.dispatch({
      type: 'resource/fetchImageList',
      payload: params,
    });
    this.setState({
      UIParams: states,
      Queryers: params,
    });
  }
  //批量
  handleBatchOperation = (actionName, keys) => {
    Message.info('暂不支持批量操作!');
  }
  render() {
    const { UIParams } = this.state;
    const { resource, loading } = this.props;
    const { list, totalSize, pageSize, pageNo } = resource;
    const batchActions = [{
      key: 'delete',
      name: '批量删除',
    }, {
      key: 'edit',
      name: '批量编辑',
    }];
    const basicSearch = {
      keys: [{
        name: '图片编号',
        field: 'code',
      }, {
        name: '图片名称',
        field: 'name',
      }],
    };
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    return (
      <Card bordered={false} style={{ padding: 16 }}>
        <StandardCardList
          loading={loading}
          component={PictureItem}
          keepUIState={{...UIParams}}
          dataSource={pictureItemFormatter(list)}
          header={{
            basicSearch,
            onFilterClick: this.handleFilterOperation,
            onCreateClick: this.handleCreateOperation,
          }}
          footer={{
            pagination,
            batchActions,
            onBatchClick: this.handleBatchOperation,
          }}
          grid={{ gutter: 16, xxl: 12, xl:6, lg: 4, md: 3, sm: 2, xs: 1 }}
          onDelete={this.handleDeleteOperation}
        />
      </Card>
    );
  }
}
