import React, { Component } from 'react';
import { Card, Divider, Badge, Input, Select, Icon } from 'antd';
import { connect } from 'dva';
import { ossHost } from '../../utils/config';
import moment from 'moment';
import { StandardTableList } from '../../components/RBList';
import styles from './VideoList.less';

@connect(({resource, loading}) => ({
  resource,
  loading: loading.models.resource,
}))
export default class PictureListPage extends Component {
  componentDidMount() {
    this.props.dispatch({
      type: 'resource/fetchImageList',
      payload: {}
    });
  }
  render() {
    const { loading, resource } = this.props;
    const { list, total, current, pageSize } = resource;

    const pagination = {
      total,
      current,
      pageSize,
    };
    const renderThumbPic = (url) => {
      return (
        <div className={styles.thumbPic}>
          <img src={url} alt="thumb"/>
        </div>
      );
    }
    const renderMetaData = ({code,name}) => {
      return (
        <div className={styles.meta}>
          <p>{name}</p>
          <p>{code}</p>
        </div>
      );
    }
    const renderStatus = (status) => {
      if (status === 'NORMAL') {
        return (
          <Badge status="success" text="正常"/>
        );
      } else {
        return (
          <Badge status="error" text="删除"/>
        );
      }
    }
    const renderActions = () => {
      return (
        <div>
          <a>查看</a>
          <Divider type="vertical"/>
          <a>编辑</a>
          <Divider type="vertical"/>
          <a>删除</a>
        </div>
      );
    }

    const columns = [{
      title: '缩略图',
      key: 1,
      dataIndex: 'path',
      render: (text) => renderThumbPic(`${ossHost}/${text}`),
      width: '15%',
    }, {
      title: '名称/编号',
      key: 2,
      dataIndex: 'meta',
      render: (_, record) => renderMetaData(record),
      width: '25%',
    }, {
      title: '格式',
      key: 3,
      dataIndex: 'format',
      width: '10%',
    }, {
      title: '大小',
      key: 4,
      dataIndex: 'size',
      width: '10%',
    }, {
      title: '状态',
      key: 5,
      dataIndex: 'status',
      render: (text) => renderStatus(text),
      width: '8%',
    }, {
      title: '更新日期',
      key: 6,
      dataIndex: 'gmtModified',
      render: (text) => moment(text).format('YYYY-MM-DD HH:mm:ss'),
      width: '17%',
    }, {
      title: '操作',
      key: 7,
      dataIndex: 'action',
      render: () => renderActions(),
      width: '15%',
    }];
    return (
      <Card bordered={false} style={{ padding: 16 }}>
        <StandardTableList
          columns={columns}
          selectedRows={[]}
          loading={loading}
          dataSource={list}
          pagination={pagination}
        />
      </Card>
    );
  }
}
